======================
django-stripe-payments
======================

a payments Django app for Stripe

.. image:: https://travis-ci.org/eldarion/django-stripe-payments.png
    :target: https://travis-ci.org/eldarion/django-stripe-payments

This app allows you to process one off charges as well as signup users for
recurring subscriptions managed by Stripe.

Documentation can be found at http://django-stripe-payments.readthedocs.org


Development
-----------

To run test suite::

    $ pip install Django stripe django-nose django-jsonfield mock
    $ python runtests.py


Commercial Support
------------------

This app, and many others like it, have been built in support of many of Eldarion's
own sites, and sites of our clients. We would love to help you on your next project
so get in touch by dropping us a note at info@eldarion.com.
